@@ -1,5 +1,6 @@
 ###   Functions to fit the WEV model
 ### Model version described by (Rausch et al., 2023)
+
 fitCEV <-
   function(N_SA_RA, N_SA_RB, N_SB_RA, N_SB_RB,
            nInits, nRestart, nRatings, nCond, nTrials){
@@ -15,8 +16,8 @@ fitCEV <-
 
     inits <- data.frame(matrix(data=NA, nrow= nrow(temp), ncol = nCond + nRatings*2 + 1))
     if(nCond==1)  {
-      inits[,1] <-  log(temp$maxD)  }
-    else{
+      inits[,1] <-  log(temp$maxD)
+    }else{
       inits[,1:(nCond)] <-  log(t(mapply(function(maxD) diff(seq(0, maxD, length.out = nCond+1)), temp$maxD)))
     }
     if (nRatings > 3){
